.. Python FTR documentation master file, created by
   sphinx-quickstart on Tue Mar 10 09:11:24 2015.

Website Configuration objects
=============================

.. automodule:: ftr.config
        :members:

